# ASN.1 module Ieee1609Dot2Dot1CamRaInterface
 OID: _{iso(1) identified-organization(3) ieee(111) standards-association-numbered-series-standards(2) wave-stds(1609) dot2(2) extension-standards(255) dot1(1) interfaces(1) cam-ra(19) major-version-2(2) minor-version-2(2)}_
 @note Section references in this file are to clauses in IEEE Std
 1609.2.1 unless indicated otherwise. Full forms of acronyms and
 abbreviations used in this file are specified in 3.2.
 

## Imports:
 * **[Ieee1609Dot2BaseTypes](Ieee1609Dot2BaseTypes.md)** *{iso(1) identified-organization(3) ieee(111) standards-association-numbered-series-standards(2) wave-stds(1609) dot2(2) base(1) base-types(2) major-version-2(2) minor-version-3(3)} WITH SUCCESSORS*<br/>
  
## Data Elements:
### <a name="CamRaInterfacePdu"></a>CamRaInterfacePdu
This is the parent structure for all structures exchanged between
 the CAM and the RA during ACPC enrollment. An overview of this structure
 is as follows:

Fields:
* raCamBatchRequest of type [**RaCamBatchRequest**](#RaCamBatchRequest) <br>
  contains the ACPC blinded key batch request sent
   by the RA to the CAM.


* camRaBatchResponse of type [**CamRaBatchResponse**](#CamRaBatchResponse) <br>
  contains the CAM's response to RaCamBatchRequest.
   


   
```asn1
CamRaInterfacePdu ::= CHOICE {
  raCamBatchRequest   RaCamBatchRequest,
  camRaBatchResponse  CamRaBatchResponse,
  ...
}
```

### <a name="RaCamBatchRequest"></a>RaCamBatchRequest
This structure contains parameters needed to request a blinded batch
 of keys for the EE during ACPC enrollment. An overview of this structure
 is as follows:

Fields:
* version of type [**Uint8**](Ieee1609Dot2BaseTypes.md#Uint8)  (2)<br>
  contains the current version of the structure.


* eeId of type **OCTET STRING**  (SIZE(5))<br>
  contains the EE's ID generated by the RA for the production of
   ACPC batch keys by the CAM.


   
* periodList of type **SEQUENCE**  OF IValue<br>
  contains the list of i-periods covered by the batch.
   


   
```asn1
RaCamBatchRequest ::= SEQUENCE {
  version     Uint8 (2),
  eeId        OCTET STRING (SIZE(5)),
  periodList  SEQUENCE OF IValue,
  ...
}
```

### <a name="CamRaBatchResponse"></a>CamRaBatchResponse
This structure contains a blinded batch of keys for the EE during
 ACPC enrollment. An overview of this structure is as follows:

Fields:
* version of type [**Uint8**](Ieee1609Dot2BaseTypes.md#Uint8)  (2)<br>
  contains the current version of the structure.


* requestHash of type [**HashedId8**](Ieee1609Dot2BaseTypes.md#HashedId8) <br>
  contains the hash of the corresponding request
   RaCamBatchRequest.


   
* batch of type **SEQUENCE**  OF BlindedKey<br>
  contains a sequence of blinded keys, each mapped to one
   IValue from the periodList field of the request.
   


   
```asn1
CamRaBatchResponse ::= SEQUENCE {
  version      Uint8 (2),
  requestHash  HashedId8,
  batch        SEQUENCE OF BlindedKey,
  ...
}
```


### <a name="BlindedKey"></a>BlindedKey
This is a blinded ACPC encryption key produced by the CAM.
```asn1
BlindedKey ::= EccP256CurvePoint
```



This is a blinded ACPC encryption key produced by the CAM.


